@@ -62,7 +62,7 @@ const DEFAULT_DICTIONARY_ENABLED: bool = true;
 const DEFAULT_DICTIONARY_PAGE_SIZE_LIMIT: usize = DEFAULT_PAGE_SIZE;
 const DEFAULT_STATISTICS_ENABLED: bool = true;
 const DEFAULT_MAX_STATISTICS_SIZE: usize = 4096;
-const DEFAULT_MAX_ROW_GROUP_SIZE: usize = 1024 * 1024;
+const DEFAULT_MAX_ROW_GROUP_SIZE: usize = 128 * 1024 * 1024;
 const DEFAULT_CREATED_BY: &str = env!("PARQUET_CREATED_BY");
 
 /// Parquet writer version.
@@ -129,7 +129,7 @@ impl WriterProperties {
         self.write_batch_size
     }
 
-    /// Returns maximum number of rows in a row group.
+    /// Returns max size for a row group.
     pub fn max_row_group_size(&self) -> usize {
         self.max_row_group_size
     }
@@ -145,8 +145,8 @@ impl WriterProperties {
     }
 
     /// Returns `key_value_metadata` KeyValue pairs.
-    pub fn key_value_metadata(&self) -> Option<&Vec<KeyValue>> {
-        self.key_value_metadata.as_ref()
+    pub fn key_value_metadata(&self) -> &Option<Vec<KeyValue>> {
+        &self.key_value_metadata
     }
 
     /// Returns encoding for a data page, when dictionary encoding is enabled.
@@ -288,7 +288,7 @@ impl WriterPropertiesBuilder {
         self
     }
 
-    /// Sets maximum number of rows in a row group.
+    /// Sets max size for a row group.
     pub fn set_max_row_group_size(mut self, value: usize) -> Self {
         assert!(value > 0, "Cannot have a 0 max row group size");
         self.max_row_group_size = value;
@@ -523,7 +523,7 @@ mod tests {
         assert_eq!(props.max_row_group_size(), DEFAULT_MAX_ROW_GROUP_SIZE);
         assert_eq!(props.writer_version(), DEFAULT_WRITER_VERSION);
         assert_eq!(props.created_by(), DEFAULT_CREATED_BY);
-        assert_eq!(props.key_value_metadata(), None);
+        assert_eq!(props.key_value_metadata(), &None);
         assert_eq!(props.encoding(&ColumnPath::from("col")), None);
         assert_eq!(
             props.compression(&ColumnPath::from("col")),
@@ -631,9 +631,7 @@ mod tests {
         assert_eq!(props.created_by(), "default");
         assert_eq!(
             props.key_value_metadata(),
-            Some(&vec![
-                KeyValue::new("key".to_string(), "value".to_string(),)
-            ])
+            &Some(vec![KeyValue::new("key".to_string(), "value".to_string(),)])
         );
 
         assert_eq!(
@@ -641,8 +639,8 @@ mod tests {
             Some(Encoding::DELTA_BINARY_PACKED)
         );
         assert_eq!(props.compression(&ColumnPath::from("a")), Compression::GZIP);
-        assert!(!props.dictionary_enabled(&ColumnPath::from("a")));
-        assert!(!props.statistics_enabled(&ColumnPath::from("a")));
+        assert_eq!(props.dictionary_enabled(&ColumnPath::from("a")), false);
+        assert_eq!(props.statistics_enabled(&ColumnPath::from("a")), false);
         assert_eq!(props.max_statistics_size(&ColumnPath::from("a")), 50);
 
         assert_eq!(
@@ -653,8 +651,8 @@ mod tests {
             props.compression(&ColumnPath::from("col")),
             Compression::SNAPPY
         );
-        assert!(props.dictionary_enabled(&ColumnPath::from("col")));
-        assert!(props.statistics_enabled(&ColumnPath::from("col")));
+        assert_eq!(props.dictionary_enabled(&ColumnPath::from("col")), true);
+        assert_eq!(props.statistics_enabled(&ColumnPath::from("col")), true);
         assert_eq!(props.max_statistics_size(&ColumnPath::from("col")), 123);
     }
 
